from setuptools import setup, find_packages

setup(
    name="vaassdk",
    version="1.0.3",
    description="vaassdk",
    author="yilan",
    url="https://github.com/yilanyun/vaas-sdk-python.git",
    packages=find_packages()
)
